@@ -14,19 +14,6 @@
 #' @source \url{https://data.linz.govt.nz/layer/51153-nz-coastlines-and-islands-polygons-topo-150k/}
 "nz"
 
-#' @title New Zealand coastline with regions.
-#' @description New Zealand coastline, excluding the Chathams, with regional boundaries simplified for ggplot.
-#' @format An \code{sf} object.
-#' @examples
-#' nz_region
-#'
-#' ggplot_sf(nz_region)
-#'
-#' ggplot_sf(dplyr::filter(nz_region, region_code == "09"))
-#'
-#' @source \url{https://datafinder.stats.govt.nz/layer/98765-regional-council-2019-clipped-generalised/}
-"nz_region"
-
 #' @title Example sf object of New Zealand livestock.
 #' @description Example sf object of New Zealand livestock.
 #' @format An \code{sf} object.
